==> vtk6-6.3.0-2-armv6h.pkg.tar.xz: vtk/vtkSTLReader.java <==
// java wrapper for vtkSTLReader object
//

package vtk;
import vtk.*;

public class vtkSTLReader extends vtkAbstractPolyDataReader
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetMTime_2();
  public int GetMTime()
    { return GetMTime_2(); }

  private native void SetMerging_3(int id0);
  public void SetMerging(int id0)
    { SetMerging_3(id0); }

  private native int GetMerging_4();
  public int GetMerging()
    { return GetMerging_4(); }

  private native void MergingOn_5();
  public void MergingOn()
    { MergingOn_5(); }

  private native void MergingOff_6();
  public void MergingOff()
    { MergingOff_6(); }

  private native void SetScalarTags_7(int id0);
  public void SetScalarTags(int id0)
    { SetScalarTags_7(id0); }

  private native int GetScalarTags_8();
  public int GetScalarTags()
    { return GetScalarTags_8(); }

  private native void ScalarTagsOn_9();
  public void ScalarTagsOn()
    { ScalarTagsOn_9(); }

  private native void ScalarTagsOff_10();
  public void ScalarTagsOff()
    { ScalarTagsOff_10(); }

  private native void SetLocator_11(vtkIncrementalPointLocator id0);
  public void SetLocator(vtkIncrementalPointLocator id0)
    { SetLocator_11(id0); }

  private native long GetLocator_12();
  public vtkIncrementalPointLocator GetLocator() {
    long temp = GetLocator_12();

    if (temp == 0) return null;
    return (vtkIncrementalPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkSTLReader() { super(); }

  public vtkSTLReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv6h.pkg.tar.xz: vtk/vtkSTLReader.java <==
// java wrapper for vtkSTLReader object
//

package vtk;
import vtk.*;

public class vtkSTLReader extends vtkAbstractPolyDataReader
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetMTime_2();
  public int GetMTime()
    { return GetMTime_2(); }

  private native void SetMerging_3(int id0);
  public void SetMerging(int id0)
    { SetMerging_3(id0); }

  private native int GetMerging_4();
  public int GetMerging()
    { return GetMerging_4(); }

  private native void MergingOn_5();
  public void MergingOn()
    { MergingOn_5(); }

  private native void MergingOff_6();
  public void MergingOff()
    { MergingOff_6(); }

  private native void SetScalarTags_7(int id0);
  public void SetScalarTags(int id0)
    { SetScalarTags_7(id0); }

  private native int GetScalarTags_8();
  public int GetScalarTags()
    { return GetScalarTags_8(); }

  private native void ScalarTagsOn_9();
  public void ScalarTagsOn()
    { ScalarTagsOn_9(); }

  private native void ScalarTagsOff_10();
  public void ScalarTagsOff()
    { ScalarTagsOff_10(); }

  private native void SetLocator_11(vtkIncrementalPointLocator id0);
  public void SetLocator(vtkIncrementalPointLocator id0)
    { SetLocator_11(id0); }

  private native long GetLocator_12();
  public vtkIncrementalPointLocator GetLocator() {
    long temp = GetLocator_12();

    if (temp == 0) return null;
    return (vtkIncrementalPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native String GetHeader_13();
  public String GetHeader()
    { return GetHeader_13(); }

  private native long GetBinaryHeader_14();
  public vtkUnsignedCharArray GetBinaryHeader() {
    long temp = GetBinaryHeader_14();

    if (temp == 0) return null;
    return (vtkUnsignedCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkSTLReader() { super(); }

  public vtkSTLReader(long id) { super(id); }
  public native long   VTKInit();

}
